@@ -10,7 +10,7 @@ addSpatialReferences <- function(ID, SRSID, Name, IsGeographic, Notes){
 	}
 	for(i in seq(along=ID)){
 		#check existing
-		if(NROW(IgetSpatialReference(getOption("odm.handler"), ID=ID[i], SRSName=Name[i], SRSID=SRSID[i], IsGeographic=IsGeographic, Notes=Notes[i]))>0){
+		if(NROW(IgetSpatialReference(getOption("odm.handler"), ID=ID[i], SRSName=Name[i], SRSID=SRSID[i], IsGeographic=IsGeographic, Notes=Notes[i],exact=TRUE))>0){
 			warning(paste("Skiping existing entry:", Name[i]))
 			next
 		}
