@@ -3,7 +3,7 @@ addUnits <- function(Name, Type, Abbreviation){
 	stopifnot(length(Name)==length(Abbreviation))
 	for(i in seq(along=Name)){
 		#check existing
-		if(NROW(IgetUnits(getOption("odm.handler"), Name=Name[i], Type=Type[i], Abbreviation=Abbreviation[i]))>0){
+		if(NROW(IgetUnits(getOption("odm.handler"), Name=Name[i], Type=Type[i], Abbreviation=Abbreviation[i], exact=TRUE))>0){
 			warning(paste("Skiping existing entry:", Name[i]))
 			next
 		}
